@@ -2,7 +2,6 @@
 
 from __future__ import unicode_literals
 
-import warnings
 from pkg_resources import parse_version
 
 from bleach.linkifier import (
@@ -18,24 +17,10 @@ from bleach.sanitizer import (
 )
 
 
-import html5lib
-try:
-    _html5lib_version = html5lib.__version__.split('.')
-    if len(_html5lib_version) < 2:
-        _html5lib_version = _html5lib_version + ['0']
-except Exception:
-    _h5ml5lib_version = ['unknown', 'unknown']
-
-
-# Bleach 3.0.0 won't support html5lib-python < 1.0.0.
-if _html5lib_version < ['1', '0'] or 'b' in _html5lib_version[1]:
-    warnings.warn('Support for html5lib-python < 1.0.0 is deprecated.', DeprecationWarning)
-
-
 # yyyymmdd
-__releasedate__ = '20171207'
+__releasedate__ = '20200213'
 # x.y.z or x.y.z.dev0 -- semver
-__version__ = '2.1.2'
+__version__ = '3.1.1'
 VERSION = parse_version(__version__)
 
 
